Waves CLI
===============================

version number: 0.0.39
author: Spacetime Labs

Overview
--------

A Waves CLI basic and commons modules

Installation / Usage
--------------------

To install use pip:

    $ pip install wavescli


Or clone the repo:

    $ git clone https://github.com/spacetimelabs/wavescli.git
    $ python setup.py install
    
Contributing
------------

TBD

Example
-------

TBD